# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .transliteration_modules import TransliterationModules as TransliterationModules_32090f64
    from .transliteration_modules_new import TransliterationModulesNew as TransliterationModulesNew_6260108e
    from ..lang.locale import Locale as Locale_70d308fa

class XTransliteration(XInterface_8f010a43):
    """
    Character conversions like case folding or Hiragana to Katakana.
    
    Transliteration is a character to character conversion but it is not always a one to one mapping between characters. Transliteration modules are primarily used by collation, and search and replace modules to perform approximate search. It can also be used to format the numbers in different numbering systems.
    
    In order to select transliteration modules for different purposes, they are classified with attributes of TransliterationType.
    
    For Western languages there would be three transliteration modules available to compare two mixed case strings: upper to lower, lower to upper, and ignore case.
    
    A typical calling sequence of transliteration is
    
    or another one is

    See Also:
        `API XTransliteration <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XTransliteration.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.i18n.XTransliteration']

    def compareString(self, aStr1: str, aStr2: str) -> int:
        """
        Compare 2 strings as per this transliteration.
        
        It translates both strings before comparing them.
        """
    def compareSubstring(self, aStr1: str, nOff1: int, nLen1: int, aStr2: str, nOff2: int, nLen2: int) -> int:
        """
        Compare 2 substrings as per this transliteration.
        
        It translates both substrings before comparing them.
        """
    def equals(self, aStr1: str, nPos1: int, nCount1: int, rMatch1: int, aStr2: str, nPos2: int, nCount2: int, rMatch2: int) -> bool:
        """
        Match two substrings and find if they are equivalent as per this transliteration.
        
        This method can be called if the object has TransliterationType IGNORE attribute.
        
        Returns the number of matched code points in any case, even if strings are not equal, for example:
        equals( \"a\", 0, 1, nMatch1, \"aaa\", 0, 3, nMatch2 )
        returns FALSE and nMatch:=1 and nMatch2:=1
        equals( \"aab\", 0, 3, nMatch1, \"aaa\", 0, 3, nMatch2 )
        returns FALSE and nMatch:=2 and nMatch2:=2

        * ``rMatch1`` is an out direction argument.
        * ``rMatch2`` is an out direction argument.
        """
    def folding(self, aInStr: str, nStartPos: int, nCount: int, rOffset: 'typing.Tuple[int, ...]') -> str:
        """

        * ``rOffset`` is an out direction argument.
        """
    def getAvailableModules(self, aLocale: 'Locale_70d308fa', nType: int) -> 'typing.Tuple[str, ...]':
        """
        List the available transliteration modules for a given locale.
        
        It can be filtered based on its type.
        """
    def getName(self) -> str:
        """
        Unique ASCII name to identify a module.
        
        This name is used to get its localized name for menus, dialogs etc. The behavior is undefined for TransliterationType.CASCADE modules.
        """
    def getType(self) -> int:
        """
        Return the attribute(s) associated with this transliteration object, as defined in TransliterationType.
        
        The value is determined by the transliteration modules. For example, for UPPERCASE_LOWERCASE, a ONE_TO_ONE is returned, for IGNORE_CASE, IGNORE is returned.
        """
    def loadModule(self, eModType: 'TransliterationModules_32090f64', aLocale: 'Locale_70d308fa') -> None:
        """
        Load instance of predefined module - old style method.
        """
    def loadModuleByImplName(self, aImplName: str, aLocale: 'Locale_70d308fa') -> None:
        """
        Load instance of UNO registered module.
        
        Each transliteration module is registered under a different service name. The convention for the service name is com.sun.star.i18n.Transliteration.l10n.{implName}. The {implName} is a unique name used to identify a module. The implName is used to get a localized name for the transliteration module. The implName is used in locale data to list the available transliteration modules for the locale. There are some transliteration modules that are always available. The names of those modules are listed as enum TransliterationModules names. For modules not listed there it is possible to load them directly by their implName.
        """
    def loadModuleNew(self, aModType: 'typing.Tuple[TransliterationModulesNew_6260108e, ...]', aLocale: 'Locale_70d308fa') -> None:
        """
        Load a sequence of instances of predefined modules - supersedes method XTransliteration.loadModule().
        """
    def loadModulesByImplNames(self, aImplNameList: 'typing.Tuple[str, ...]', aLocale: 'Locale_70d308fa') -> None:
        """
        Load a sequence of instances of transliteration modules.
        
        Output of one module is fed as input to the next module in the sequence. The object created by this call has TransliterationType CASCADE and IGNORE types.
        """
    def transliterate(self, aInStr: str, nStartPos: int, nCount: int, rOffset: 'typing.Tuple[int, ...]') -> str:
        """
        Transliterate a substring.
        
        This method can be called if the object doesn't have TransliterationType IGNORE attribute.

        * ``rOffset`` is an out direction argument.
        """
    def transliterateRange(self, aStr1: str, aStr2: str) -> 'typing.Tuple[str, ...]':
        """
        Transliterate one set of characters to another.
        
        This method is intended for getting corresponding ranges and can be called if the object has TransliterationType IGNORE attribute.
        
        For example: generic CASE_IGNORE transliterateRange( \"a\", \"i\" ) returns {\"A\",\"I\",\"a\",\"i\"}, transliterateRange( \"a\", \"a\" ) returns {\"A\",\"A\",\"a\",\"a\"}.
        
        Use this transliteration to create regular expressions like [a-i] --> [A-Ia-i].
        """




#!/usr/bin/env python
import os
import pathlib
from setuptools import setup, find_packages

# prevent com.sun.star.__init__.py from raising an import error.
os.environ["ooouno_ignore_import_error"] = "True"
from com.sun.star import __version__
# VERSION = "0.4.5"
# __version__ is not part of ooo_uno_tmpl output for com.sun.star.__init__.py
# for this reason when replacing current __init__.py __version__ must be added again.
VERSION = __version__
PKG_NAME = 'types-unopy'

def package_files(directory):
    paths = []
    for (path, directories, filenames) in os.walk(directory):
        for filename in filenames:
            paths.append(os.path.join('..', path, filename))
    return paths

# The directory containing this file
HERE = pathlib.Path(__file__).parent
# The text of the README file
with open(HERE / "README.rst") as fh:
    README = fh.read()

src_path = str(HERE / 'com')

PKG = find_packages(include='com')
extra_files = package_files(src_path)
setup(
    name=PKG_NAME,
    version=VERSION,
    package_data={'': extra_files},
    python_requires='>=3.7.0',
    url="https://github.com/Amourspirit/python-types-unopy",
    packages=['com'],
    author=":Barry-Thomas-Paul: Moss",
    author_email='bigbytetech@gmail.com',
    license="Apache Software License",
    keywords=['libreoffice', 'openoffice', 'typings', 'uno', 'ooouno', 'pyuno'],
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
        "Environment :: Other Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Topic :: Office/Business",
        "Typing :: Typed",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    install_requires=[
        'typing_extensions>=3.7.4.3;python_version<"3.7"',
        'types-uno-script>=0.1.0'
    ],
    description="Type annotations for LibreOffice API",
    long_description_content_type="text/x-rst",
    long_description=README
)



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing.framework
from typing_extensions import Literal
import typing
from .x_resource import XResource as XResource_3bcd0f90
if typing.TYPE_CHECKING:
    from ...awt.x_window import XWindow as XWindow_713b0924
    from ...rendering.x_canvas import XCanvas as XCanvas_b19b0b7a

class XPane(XResource_3bcd0f90):
    """
    A pane is an abstraction of a window and is one of the resources managed by the drawing framework.
    
    Apart from the area that displays a view a pane may contain other parts like title, menu, closer button.
    
    The URL prefix of panes is private:resource/floater

    See Also:
        `API XPane <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XPane.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.framework.XPane']

    def getCanvas(self) -> 'XCanvas_b19b0b7a':
        """
        Return the com.sun.star.awt.XCanvas of the pane.
        
        The com.sun.star.rendering.XCanvas object is expected to be associated with the com.sun.star.awt.XWindow object returned by getWindow().
        """
    def getWindow(self) -> 'XWindow_713b0924':
        """
        Return the com.sun.star.awt.XWindow of the pane that is used to display a view.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .filter_connection import FilterConnection as FilterConnection_f01f0d97
from .filter_operator import FilterOperator as FilterOperator_d5c60cd3


class TableFilterField(object):
    """
    Struct Class

    describes a single condition in a filter descriptor.

    See Also:
        `API TableFilterField <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1TableFilterField.html>`_
    """
    typeName: Literal['com.sun.star.sheet.TableFilterField']

    def __init__(self, Connection: typing.Optional[FilterConnection_f01f0d97] = ..., Field: typing.Optional[int] = ..., Operator: typing.Optional[FilterOperator_d5c60cd3] = ..., IsNumeric: typing.Optional[bool] = ..., NumericValue: typing.Optional[float] = ..., StringValue: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Connection (FilterConnection, optional): Connection value.
            Field (int, optional): Field value.
            Operator (FilterOperator, optional): Operator value.
            IsNumeric (bool, optional): IsNumeric value.
            NumericValue (float, optional): NumericValue value.
            StringValue (str, optional): StringValue value.
        """


    @property
    def Connection(self) -> FilterConnection_f01f0d97:
        """
        specifies how the condition is connected to the previous condition.
        """


    @property
    def Field(self) -> int:
        """
        specifies which field (column) is used for the condition.
        """


    @property
    def Operator(self) -> FilterOperator_d5c60cd3:
        """
        specifies the type of the condition.
        """


    @property
    def IsNumeric(self) -> bool:
        """
        selects whether the TableFilterField.NumericValue or the TableFilterField.StringValue is used.
        """


    @property
    def NumericValue(self) -> float:
        """
        specifies a numeric value for the condition.
        """


    @property
    def StringValue(self) -> str:
        """
        specifies a string value for the condition.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
from .x_accessible_action import XAccessibleAction as XAccessibleAction_7ccc1114

class XAccessibleHyperlink(XAccessibleAction_7ccc1114):
    """
    Implement this interface to represent a hyperlink or a group of hyperlinks.
    
    Single hyperlinks correspond to simple <a href> tags. Groups of hyperlinks are contained in client side image maps. Linked objects and anchors are implementation dependent. This interface inherits the XAccessibleAction interface. Especially that interface's XAccessibleAction.getActionCount() method is needed to obtain a maximum value for the indices passed to the XAccessibleHyperlink.getAccessibleActionAnchor() and XAccessibleHyperlink.getAccessibleActionObject() methods.
    
    Furthermore, the object that implements this interface has to be connected implicitly or explicitly with an object that implements the XAccessibleText interface. The XAccessibleHyperlink.getStartIndex() and XAccessibleHyperlink.getEndIndex() methods return indices with respect to the text exposed by that interface.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleHyperlink <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleHyperlink.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleHyperlink']

    def getAccessibleActionAnchor(self, nIndex: int) -> object:
        """
        Returns an object that represents the link anchor, as appropriate for that link.
        
        For an HTML link for example, this method would return the string enclosed by the &lt&a href> tag.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleActionObject(self, nIndex: int) -> object:
        """
        Returns an object that represents the link anchor, as appropriate for that link.
        
        For an HTML link for example, this method would return the URL of the &lt&a href> tag.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getEndIndex(self) -> int:
        """
        Returns the index at which the textual representation of the hyperlink (group) ends.
        
        The returned value relates to the XAccessibleText interface that owns this hyperlink.
        """
    def getStartIndex(self) -> int:
        """
        Returns the index at which the textual representation of the hyperlink (group) starts.
        
        The returned value relates to the XAccessibleText interface that owns this hyperlink.
        """
    def isValid(self) -> bool:
        """
        Returns whether the document referenced by this links is still valid.
        
        This is a volatile state that may change without further warning like e.g. sending an appropriate event.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
from .x_type_description import XTypeDescription as XTypeDescription_3c210fb1

class XPropertyTypeDescription(XTypeDescription_3c210fb1):
    """
    Reflects a property.
    
    The type class of this type is com.sun.star.uno.TypeClass.PROPERTY.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XPropertyTypeDescription <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XPropertyTypeDescription.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XPropertyTypeDescription']

    def getPropertyFlags(self) -> int:
        """
        The possible values are defined in com.sun.star.beans.PropertyAttribute
        """
    def getPropertyTypeDescription(self) -> 'XTypeDescription_3c210fb1':
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.beans
from typing_extensions import Literal


class TolerantPropertySetResultType(object):
    """
    Const

    specifies the possible failure types when using the com.sun.star.beans.XTolerantMultiPropertySet interface.
    
    It usually matches one of the exception types that may occur when using the com.sun.star.beans.XPropertySet or com.sun.star.beans.XMultiPropertySet interfaces.

    See Also:
        `API TolerantPropertySetResultType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1beans_1_1TolerantPropertySetResultType.html>`_
    """
    SUCCESS: Literal[0]
    """
    the property has been successfully set or retrieved.
    """
    UNKNOWN_PROPERTY: Literal[1]
    """
    the property is not available.
    
    For example if a com.sun.star.beans.UnknownPropertyException was caught.
    """
    ILLEGAL_ARGUMENT: Literal[2]
    """
    the value used with the property is not valid.
    
    For example if a com.sun.star.lang.IllegalArgumentException was caught.
    """
    PROPERTY_VETO: Literal[3]
    """
    the property could not be changed at that time.
    
    For example if a com.sun.star.beans.PropertyVetoException was caught.
    """
    WRAPPED_TARGET: Literal[4]
    """
    a com.sun.star.lang.WrappedTargetException did occur.
    """
    UNKNOWN_FAILURE: Literal[5]
    """
    the operation failed and the reason is not known.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
from typing_extensions import Literal
from ..beans.x_fast_property_set import XFastPropertySet as XFastPropertySet_ee6b0d88
from .x_draw_view import XDrawView as XDrawView_b0b80b75
from ..view.x_selection_supplier import XSelectionSupplier as XSelectionSupplier_fed20e15

class XDrawSubController(XFastPropertySet_ee6b0d88, XDrawView_b0b80b75, XSelectionSupplier_fed20e15):
    """
    View dependent part of the Draw and Impress controller.
    
    During the lifetime of an Impress application the com.sun.star.drawing.DrawingDocumentDrawView changes its sub controllers whenever the view in the center pane is replaced by another one. The sub controller handles the things that are not common to all views, i.e. properties, the current page/slide, and the selection.

    See Also:
        `API XDrawSubController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawSubController.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.XDrawSubController']





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
from enum import Enum

class ChartErrorCategory(Enum):
    """
    Enum

    

    See Also:
        `API ChartErrorCategory <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart.html#a5dc5747cfef559a2185b3400717ee431>`_
    """

    CONSTANT_VALUE: 'uno.Enum'
    """
    displays the same lower and upper error indicators for all data points.
    
    The values for these are given as absolute numbers in ChartStatistics.ConstantErrorLow and ChartStatistics.ConstantErrorHigh
    """
    ERROR_MARGIN: 'uno.Enum'
    """
    The length of the error indicators for all data points is calculated by taking the percentage given as ChartStatistics.ErrorMargin of the largest data point value.
    """
    NONE: 'uno.Enum'
    """
    error indicators are not displayed.
    
    displays no regression curve.
    
    no chart legend is displayed.
    
    displays no error indicators.
    """
    PERCENT: 'uno.Enum'
    """
    The length of the error indicators is calculated for each data point by taking the percentage given as ChartStatistics.PercentageError of its value.
    """
    STANDARD_DEVIATION: 'uno.Enum'
    """
    displays error indicators for the standard deviation (square root of variance) of the data row.
    """
    VARIANCE: 'uno.Enum'
    """
    displays error indicators for the variance of the data row.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal


class OpenMode(object):
    """
    Const

    These are the possible values for OpenCommandArgument.Mode.

    See Also:
        `API OpenMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1OpenMode.html>`_
    """
    ALL: Literal[0]
    """
    open a folder, include all children in result set (documents and folders).
    """
    FOLDERS: Literal[1]
    """
    open a folder, include only children, that are folders, in result set.
    """
    DOCUMENTS: Literal[3]
    """
    open a folder, include only children, that are documents, in result set.
    """
    DOCUMENT: Literal[2]
    """
    open a document.
    
    There are no special requirements for data access sharing.
    
    Note: There must be a data sink supplied in the OpenCommandArgument struct, if this value is set. This sink will be used by the content implementation to supply the document data.
    """
    DOCUMENT_SHARE_DENY_NONE: Literal[4]
    """
    open a document.
    
    Allow shared read and write access.
    
    Note: There must be a data sink supplied in the OpenCommandArgument struct, if this value is set. This sink will be used by the content implementation to supply the document data.
    """
    DOCUMENT_SHARE_DENY_WRITE: Literal[5]
    """
    open a document.
    
    Deny shared write access.
    
    Note: There must be a data sink supplied in the OpenCommandArgument struct, if this value is set. This sink will be used by the content implementation to supply the document data.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.bridge.oleautomation
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class NamedArgument(object):
    """
    Struct Class

    represents a named argument in a call to a method of an Automation object.
    
    The Automation bridge accepts values of NamedArgument when a call to an Automation object is made. The call is done through the com.sun.star.script.XInvocation.invoke() method, which takes all arguments in a sequence of anys. Usually the order of the arguments must correspond to the order of arguments in the Automation method. By using instances of NamedArgument the arguments in the sequence can be unordered. The Automation object being called must support named arguments, otherwise the call fails.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API NamedArgument <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1NamedArgument.html>`_
    """
    typeName: Literal['com.sun.star.bridge.oleautomation.NamedArgument']

    def __init__(self, Name: typing.Optional[str] = ..., Value: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Value (object, optional): Value value.
        """


    @property
    def Name(self) -> str:
        """
        The name of the argument, for which NamedArgument.Value is intended.
        """


    @property
    def Value(self) -> object:
        """
        The value of the argument whose name is the one as contained in the member Name.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class ParseResult(object):
    """
    Struct Class

    Parser results returned by XCharacterClassification.parseAnyToken() and XCharacterClassification.parsePredefinedToken().

    See Also:
        `API ParseResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1ParseResult.html>`_
    """
    typeName: Literal['com.sun.star.i18n.ParseResult']

    def __init__(self, LeadingWhiteSpace: typing.Optional[int] = ..., EndPos: typing.Optional[int] = ..., CharLen: typing.Optional[int] = ..., Value: typing.Optional[float] = ..., TokenType: typing.Optional[int] = ..., StartFlags: typing.Optional[int] = ..., ContFlags: typing.Optional[int] = ..., DequotedNameOrString: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            LeadingWhiteSpace (int, optional): LeadingWhiteSpace value.
            EndPos (int, optional): EndPos value.
            CharLen (int, optional): CharLen value.
            Value (float, optional): Value value.
            TokenType (int, optional): TokenType value.
            StartFlags (int, optional): StartFlags value.
            ContFlags (int, optional): ContFlags value.
            DequotedNameOrString (str, optional): DequotedNameOrString value.
        """


    @property
    def LeadingWhiteSpace(self) -> int:
        """
        Count of ignored leading whitespace, in UTF-16 code units, not Unicode code points.
        """


    @property
    def EndPos(self) -> int:
        """
        UTF-16 code unit index of first unprocessed character.
        """


    @property
    def CharLen(self) -> int:
        """
        Number of code points (not UTF-16 code units) of the parsed token, not including leading whitespace.
        """


    @property
    def Value(self) -> float:
        """
        Value of token in case of numeric.
        """


    @property
    def TokenType(self) -> int:
        """
        KParseType token type like KParseType.IDENTNAME.
        """


    @property
    def StartFlags(self) -> int:
        """
        KParseTokens flags of first character of actual token matched.
        
        If TokenType is a KParseType.SINGLE_QUOTE_NAME or a KParseType.DOUBLE_QUOTE_STRING the first character is the first character inside the quotes, not the quote itself.
        """


    @property
    def ContFlags(self) -> int:
        """
        KParseTokens flags of remaining characters of actual token matched.
        """


    @property
    def DequotedNameOrString(self) -> str:
        """
        If a quoted name or string is encountered the dequoted result goes here.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui.dialogs
from typing_extensions import Literal


class TemplateDescription(object):
    """
    Const

    The implementation of a FilePicker service may support the usage of different templates.
    
    The following constants define the currently specified templates.
    
    **since**
    
        LibreOffice 5.3

    See Also:
        `API TemplateDescription <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html>`_
    """
    FILEOPEN_SIMPLE: Literal[0]
    """
    A FileOpen dialog without any additional controls.
    """
    FILESAVE_SIMPLE: Literal[1]
    """
    A FileSave dialog without any additional controls.
    """
    FILESAVE_AUTOEXTENSION_PASSWORD: Literal[2]
    """
    A FileSave dialog with additional controls.
    """
    FILESAVE_AUTOEXTENSION_PASSWORD_FILTEROPTIONS: Literal[3]
    """
    A FileSave dialog with additional controls.
    """
    FILESAVE_AUTOEXTENSION_SELECTION: Literal[4]
    """
    A FileSave dialog with additional controls.
    """
    FILESAVE_AUTOEXTENSION_TEMPLATE: Literal[5]
    """
    A FileSave dialog with additional controls.
    """
    FILEOPEN_LINK_PREVIEW_IMAGE_TEMPLATE: Literal[6]
    """
    A FileOpen dialog with additional controls.
    """
    FILEOPEN_PLAY: Literal[7]
    """
    A FileOpen dialog with additional controls.
    """
    FILEOPEN_READONLY_VERSION: Literal[8]
    """
    A FileOpen dialog with additional controls.
    """
    FILEOPEN_LINK_PREVIEW: Literal[9]
    """
    A FileOpen dialog with additional controls.
    """
    FILESAVE_AUTOEXTENSION: Literal[10]
    """
    A FileSave dialog with additional controls.
    """
    FILEOPEN_PREVIEW: Literal[11]
    """
    A FileOpen dialog with additional controls.
    
    **since**
    
        LibreOffice 5.3
    """
    FILEOPEN_LINK_PLAY: Literal[12]
    """
    A FileOpen dialog with additional controls.
    
    **since**
    
        LibreOffice 5.3
    """
    FILEOPEN_LINK_PREVIEW_IMAGE_ANCHOR: Literal[13]
    """
    A FileOpen dialog with additional controls.
    
    **since**
    
        LibreOffice 6.1
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text.textfield
from ..text_field import TextField as TextField_90260a56

class HiddenParagraph(TextField_90260a56):
    """
    Service Class

    specifies service of a hidden paragraph field.

    See Also:
        `API HiddenParagraph <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1HiddenParagraph.html>`_
    """
    @property
    def Condition(self) -> str:
        """
        contains the condition.
        """
    @property
    def IsHidden(self) -> bool:
        """
        contains the result of the last evaluation of the condition.
        
        This property has to be read/written in file export/import to save and restore the result without initiation of a new evaluation.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .cell_delete_mode import CellDeleteMode as CellDeleteMode_d3830c79
    from .cell_insert_mode import CellInsertMode as CellInsertMode_d47d0c9b
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XCellRangeMovement(XInterface_8f010a43):
    """
    provides methods for moving ranges of cells in a sheet.

    See Also:
        `API XCellRangeMovement <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeMovement.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XCellRangeMovement']

    def copyRange(self, aDestination: 'CellAddress_ae5f0b56', aSource: 'CellRangeAddress_ec450d43') -> None:
        """
        copies a cell range to another position in the document.
        
        The source cell range keeps unchanged.
        """
    def insertCells(self, aRange: 'CellRangeAddress_ec450d43', nMode: 'CellInsertMode_d47d0c9b') -> None:
        """
        inserts cells, moving other cells down or right.
        
        Non-empty cells cannot be moved off the sheet.
        """
    def moveRange(self, aDestination: 'CellAddress_ae5f0b56', aSource: 'CellRangeAddress_ec450d43') -> None:
        """
        moves a cell range to another position in the document.
        
        After copying the contents of the cell range, all cells will be cleared.
        """
    def removeRange(self, aRange: 'CellRangeAddress_ec450d43', nMode: 'CellDeleteMode_d3830c79') -> None:
        """
        deletes cells, moving other cells up or left.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class Command(object):
    """
    Const

    these values specify the different command types available.

    See Also:
        `API Command <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1Command.html>`_
    """
    CONTEXTMENU: Literal[1]
    """
    specifies a requests for a context menu.
    """
    STARTDRAG: Literal[2]
    """
    specifies the beginning of a drag operation.
    """
    WHEEL: Literal[3]
    """
    specifies a mouse wheel operation.
    """
    STARTAUTOSCROLL: Literal[4]
    """
    specifies the beginning of an auto scroll operation.
    """
    AUTOSCROLL: Literal[5]
    """
    specifies an auto scroll operation.
    """
    VOICE: Literal[6]
    """
    specifies a request for a voice operation.
    """
    STARTEXTTEXTINPUT: Literal[7]
    """
    specifies the beginning of an extended text input operation.
    """
    EXTTEXTINPUT: Literal[8]
    """
    specifies an extended text input operation.
    """
    ENDEXTTEXTINPUT: Literal[9]
    """
    specifies the end of an extended text input operation.
    """
    INPUTCONTEXTCHANGE: Literal[10]
    """
    specifies that the input context has been changed.
    """
    CURSORPOS: Literal[11]
    """
    specifies the cursor position.
    """
    PASTESELECTION: Literal[12]
    """
    specifies a paste selection command.
    """
    MODKEYCHANGE: Literal[13]
    """
    specifies that the state of a key modifier has changed.
    """
    HANGUL_HANJA_CONVERSION: Literal[14]
    """
    specifies a Hangul hanja conversion command.
    """
    USER: Literal[4096]
    """
    specifies a user-defined command.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .message_box_type import MessageBoxType as MessageBoxType_bbcc0be4
    from .x_message_box import XMessageBox as XMessageBox_98e00a9a
    from .x_window_peer import XWindowPeer as XWindowPeer_99760ab0

class XMessageBoxFactory(XInterface_8f010a43):
    """
    specifies a factory interface for creating message boxes.

    See Also:
        `API XMessageBoxFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XMessageBoxFactory.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XMessageBoxFactory']

    def createMessageBox(self, aParent: 'XWindowPeer_99760ab0', eType: 'MessageBoxType_bbcc0be4', nButtons: int, sTitle: str, sMessage: str) -> 'XMessageBox_98e00a9a':
        """
        creates a message box.
        
        This parameter must not be null.
        
        A combination of com.sun.star.awt.MessageBoxButtons
        
        A com.sun.star.awt.MessageBoxType.INFOBOX ignores this parameter, instead it uses a com.sun.star.awt.MessageBoxButtons.BUTTONS_OK.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XAccessibleValue(XInterface_8f010a43):
    """
    Implement this interface to give access to a single numerical value.
    
    The XAccessibleValue interface represents a single numerical value and should be implemented by any class that supports numerical value like scroll bars and spin boxes. This interface lets you access the value and its upper and lower bounds.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleValue <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleValue.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleValue']

    def getCurrentValue(self) -> object:
        """
        Returns the value of this object as a number.
        
        The exact return type is implementation dependent. Typical types are long and double.
        """
    def getMaximumValue(self) -> object:
        """
        Returns the maximal value that can be represented by this object.
        
        The type of the returned value is implementation dependent. It does not have to be the same type as that returned by getCurrentAccessibleValue().
        """
    def getMinimumIncrement(self) -> object:
        """
        Returns the minimal increment by which the value represented by this object can be adjusted.
        
        The type of the returned value is implementation dependent. It does not have to be the same type as that returned by getCurrentAccessibleValue().
        
        **since**
        
            LibreOffice 7.3
        """
    def getMinimumValue(self) -> object:
        """
        Returns the minimal value that can be represented by this object.
        
        The type of the returned value is implementation dependent. It does not have to be the same type as that returned by getCurrentAccessibleValue().
        """
    def setCurrentValue(self, aNumber: object) -> bool:
        """
        Sets the value of this object to the given number.
        
        The argument is clipped to the valid interval whose upper and lower bounds are returned by the methods getMaximumAccessibleValue() and getMinimumAccessibleValue(), i.e. if it is lower than the minimum value the new value will be the minimum and if it is greater than the maximum then the new value will be the maximum.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .font_slant import FontSlant as FontSlant_849509ed


class FontDescriptor(object):
    """
    Struct Class

    describes the characteristics of a font.
    
    For example, this can be used to select a font.

    See Also:
        `API FontDescriptor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1FontDescriptor.html>`_
    """
    typeName: Literal['com.sun.star.awt.FontDescriptor']

    def __init__(self, Name: typing.Optional[str] = ..., Height: typing.Optional[int] = ..., Width: typing.Optional[int] = ..., StyleName: typing.Optional[str] = ..., Family: typing.Optional[int] = ..., CharSet: typing.Optional[int] = ..., Pitch: typing.Optional[int] = ..., CharacterWidth: typing.Optional[float] = ..., Weight: typing.Optional[float] = ..., Slant: typing.Optional[FontSlant_849509ed] = ..., Underline: typing.Optional[int] = ..., Strikeout: typing.Optional[int] = ..., Orientation: typing.Optional[float] = ..., Kerning: typing.Optional[bool] = ..., WordLineMode: typing.Optional[bool] = ..., Type: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Height (int, optional): Height value.
            Width (int, optional): Width value.
            StyleName (str, optional): StyleName value.
            Family (int, optional): Family value.
            CharSet (int, optional): CharSet value.
            Pitch (int, optional): Pitch value.
            CharacterWidth (float, optional): CharacterWidth value.
            Weight (float, optional): Weight value.
            Slant (FontSlant, optional): Slant value.
            Underline (int, optional): Underline value.
            Strikeout (int, optional): Strikeout value.
            Orientation (float, optional): Orientation value.
            Kerning (bool, optional): Kerning value.
            WordLineMode (bool, optional): WordLineMode value.
            Type (int, optional): Type value.
        """


    @property
    def Name(self) -> str:
        """
        specifies the exact name of the font.
        """


    @property
    def Height(self) -> int:
        """
        specifies the height of the font in the measure of the destination.
        """


    @property
    def Width(self) -> int:
        """
        specifies the width of the font in the measure of the destination.
        """


    @property
    def StyleName(self) -> str:
        """
        specifies the style name of the font.
        """


    @property
    def Family(self) -> int:
        """
        specifies the general style of the font.
        
        Use one value out of the constant group com.sun.star.awt.FontFamily.
        """


    @property
    def CharSet(self) -> int:
        """
        specifies the character set which is supported by the font.
        
        Use one value out of the constant group com.sun.star.awt.CharSet.
        """


    @property
    def Pitch(self) -> int:
        """
        specifies the pitch of the font.
        
        Use one value out of the constant group com.sun.star.awt.FontPitch.
        """


    @property
    def CharacterWidth(self) -> float:
        """
        specifies the character width.
        
        Depending on the specified width, a font that supports this width may be selected.
        
        The value is expressed as a percentage.
        """


    @property
    def Weight(self) -> float:
        """
        specifies the thickness of the line.
        
        Depending on the specified weight, a font that supports this thickness may be selected.
        
        The value is expressed as a percentage.
        """


    @property
    def Slant(self) -> FontSlant_849509ed:
        """
        specifies the slant of the font.
        """


    @property
    def Underline(self) -> int:
        """
        specifies the kind of underlining.
        
        Use one value out of the constant group com.sun.star.awt.FontUnderline.
        """


    @property
    def Strikeout(self) -> int:
        """
        specifies the kind of strikeout.
        
        Use one value out of the constant group com.sun.star.awt.FontStrikeout.
        """


    @property
    def Orientation(self) -> float:
        """
        specifies the rotation of the font.
        
        The unit of measure is degrees; 0 is the baseline.
        """


    @property
    def Kerning(self) -> bool:
        """
        For requesting, it specifies if there is a kerning table available.
        
        For selecting, it specifies if the kerning table is to be used.
        """


    @property
    def WordLineMode(self) -> bool:
        """
        specifies if only words get underlined.
        
        TRUE means that only non-space characters get underlined, FALSE means that the spacing also gets underlined.
        
        This property is only valid if the property com.sun.star.awt.FontDescriptor.Underline is not FontUnderline.NONE.
        """


    @property
    def Type(self) -> int:
        """
        specifies the technology of the font representation.
        
        One or more values out of the constant group com.sun.star.awt.FontType can be combined by an arithmetical or-operation.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
    from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
    from .x_accelerator_configuration import XAcceleratorConfiguration as XAcceleratorConfiguration_46580ffb

class XUIConfigurationManager(XInterface_8f010a43):
    """
    specifies a user interface configuration manager interface which controls the structure of all customizable user interface elements.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XUIConfigurationManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XUIConfigurationManager.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.XUIConfigurationManager']

    def createSettings(self) -> 'XIndexContainer_1c040ebe':
        """
        creates an empty settings data container.
        """
    def getEventsManager(self) -> 'XInterface_8f010a43':
        """
        retrieves the events manager from the user interface configuration manager.
        
        Every user interface configuration manager has one events manager instance which controls the mapping of events to script URLs of a module or document.
        """
    def getImageManager(self) -> 'XInterface_8f010a43':
        """
        retrieves the image manager from the user interface configuration manager.
        
        Every user interface configuration manager has one image manager instance which controls all images of a module or document.
        """
    def getSettings(self, ResourceURL: str, bWriteable: bool) -> 'XIndexAccess_f0910d6d':
        """
        retrieves the settings of a user interface element.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getShortCutManager(self) -> 'XAcceleratorConfiguration_46580ffb':
        """
        retrieves the keyboard short cut manager from the user interface configuration manager.
        
        Every user interface configuration manager has one keyboard short cut manager instance which controls all short cuts of a module or document.
        """
    def getUIElementsInfo(self, ElementType: int) -> 'typing.Tuple[typing.Tuple[PropertyValue_c9610c73, ...], ...]':
        """
        retrieves information about all user interface elements within the user interface configuration manager.
        
        The following com.sun.star.beans.PropertyValue entries are defined inside the sequence for every user interface element.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def hasSettings(self, ResourceURL: str) -> bool:
        """
        determines if the settings of a user interface element is part the user interface configuration manager.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def insertSettings(self, NewResourceURL: str, aNewData: 'XIndexAccess_f0910d6d') -> None:
        """
        inserts the settings of a new user interface element.
        
        If the settings data is already present a com.sun.star.container.ElementExistException is thrown. If the NewResourceURL is not valid or describes an unknown type a com.sun.star.lang.IllegalArgumentException is thrown. If the configuration manager is read-only a com.sun.star.lang.IllegalAccessException is thrown.

        Raises:
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
        """
    def removeSettings(self, ResourceURL: str) -> None:
        """
        removes the settings of an existing user interface element.
        
        If the settings data cannot be found a com.sun.star.container.NoSuchElementException is thrown. If the ResourceURL is not valid or describes an unknown type a com.sun.star.lang.IllegalArgumentException is thrown. If the configuration manager is read-only a com.sun.star.lang.IllegalAccessException is thrown.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
        """
    def replaceSettings(self, ResourceURL: str, aNewData: 'XIndexAccess_f0910d6d') -> None:
        """
        replaces the settings of a user interface element with new settings.
        
        If the settings data cannot be found a com.sun.star.container.NoSuchElementException is thrown. If the ResourceURL is not valid or describes an unknown type a com.sun.star.lang.IllegalArgumentException is thrown. If the configuration manager is read-only a com.sun.star.lang.IllegalAccessException is thrown.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
        """
    def reset(self) -> None:
        """
        resets the configuration manager to the default user interface configuration data.
        
        This means that all user interface configuration data of the instance will be removed. A module based user interface configuration manager removes user defined elements, but set all other elements back to default. It is not possible to remove default elements from a module user interface configuration manager.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal


class TextMarkupType(object):
    """
    Const

    Constants to specify the type of text markup.
    
    These constants are used with XTextMarkup.commitTextMarkup()
    
    **since**
    
        OOo 2.3

    See Also:
        `API TextMarkupType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1TextMarkupType.html>`_
    """
    SPELLCHECK: Literal[1]
    """
    Markup originates from spell checking.
    """
    PROOFREADING: Literal[2]
    """
    Markup originates from proofreading.
    
    **since**
    
        OOo 3.0.1
    """
    SMARTTAG: Literal[3]
    """
    Markup originates from smart tag checking.
    """
    SENTENCE: Literal[4]
    """
    Markup originates from proofreading An invisible markup type used in proofreading API calls.
    
    **since**
    
        OOo 3.0.1
    """
    TRACK_CHANGE_INSERTION: Literal[5]
    """
    Markups originates from change tracking.
    
    **since**
    
        OOo 3.3
    """
    TRACK_CHANGE_DELETION: Literal[6]
    TRACK_CHANGE_FORMATCHANGE: Literal[7]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a

class XSessionManagerListener(XEventListener_c7230c4a):
    """

    See Also:
        `API XSessionManagerListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XSessionManagerListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XSessionManagerListener']

    def approveInteraction(self, bInteractionGranted: bool) -> None:
        """
        approveInteraction is called when an outstanding interaction request was processed by the session manager
        """
    def doRestore(self) -> bool:
        """
        returns true, if a session was restored
        """
    def doSave(self, bShutdown: bool, bCancelable: bool) -> None:
        """
        doSave gets called when a save event was issued by the session manager the listener should do what is necessary to restore the current state of the application
        
        If the listener desires to interact with the user it must first issue a user interaction request and only do so if interaction was granted
        
        When the save request is processed (with or without user interaction) the listener must call XSessionManagerClient.saveDone() on the session manager client service object.
        
        the listener may choose to ignore the saveDone() event in case no real shutdown is in progress. He still has to call XSessionManagerClient.saveDone() in that case.
        """
    def shutdownCanceled(self) -> None:
        """
        shutdownCanceled is called when a shutdown was canceled by the user The listener can cancel his saving operations.
        
        No further interaction is necessary and further calls on the session manager client service object will be ignored.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.packages.zip
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class ZipEntry(object):
    """
    Struct Class

    used to represent a ZIP file entry
    
    This interface is an IDL version of the Java interface java.util.zip.ZipFile with some minor adaptations.

    See Also:
        `API ZipEntry <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1packages_1_1zip_1_1ZipEntry.html>`_
    """
    typeName: Literal['com.sun.star.packages.zip.ZipEntry']

    def __init__(self, extra: typing.Optional[typing.Tuple[int, ...]] = ..., nVersion: typing.Optional[int] = ..., nFlag: typing.Optional[int] = ..., nMethod: typing.Optional[int] = ..., nTime: typing.Optional[int] = ..., nCrc: typing.Optional[int] = ..., nCompressedSize: typing.Optional[int] = ..., nSize: typing.Optional[int] = ..., nOffset: typing.Optional[int] = ..., nDiskNumber: typing.Optional[int] = ..., sName: typing.Optional[str] = ..., sComment: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            extra (typing.Tuple[int, ...], optional): extra value.
            nVersion (int, optional): nVersion value.
            nFlag (int, optional): nFlag value.
            nMethod (int, optional): nMethod value.
            nTime (int, optional): nTime value.
            nCrc (int, optional): nCrc value.
            nCompressedSize (int, optional): nCompressedSize value.
            nSize (int, optional): nSize value.
            nOffset (int, optional): nOffset value.
            nDiskNumber (int, optional): nDiskNumber value.
            sName (str, optional): sName value.
            sComment (str, optional): sComment value.
        """


    @property
    def extra(self) -> typing.Tuple[int, ...]:
        """
        optional extra field data for entry
        """


    @property
    def nVersion(self) -> int:
        """
        version needed to extract
        """


    @property
    def nFlag(self) -> int:
        """
        bit flags
        """


    @property
    def nMethod(self) -> int:
        """
        compression method
        """


    @property
    def nTime(self) -> int:
        """
        modification time
        """


    @property
    def nCrc(self) -> int:
        """
        CRC-32 of entry data.
        """


    @property
    def nCompressedSize(self) -> int:
        """
        uncompressed size of entry data
        """


    @property
    def nSize(self) -> int:
        """
        uncompressed size of entry data
        """


    @property
    def nOffset(self) -> int:
        """
        offset of LOC header
        """


    @property
    def nDiskNumber(self) -> int:
        """
        The number of the disk this entry is saved on.
        """


    @property
    def sName(self) -> str:
        """
        the entry name
        """


    @property
    def sComment(self) -> str:
        """
        optional comment
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.presentation
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from ..awt.x_mouse_listener import XMouseListener as XMouseListener_bc1d0bfb
    from ..awt.x_mouse_motion_listener import XMouseMotionListener as XMouseMotionListener_c6a0e71
    from ..awt.x_paint_listener import XPaintListener as XPaintListener_bb6d0bee
    from ..geometry.affine_matrix2_d import AffineMatrix2D as AffineMatrix2D_ff040da8
    from ..geometry.integer_size2_d import IntegerSize2D as IntegerSize2D_f2690d53
    from ..rendering.x_sprite_canvas import XSpriteCanvas as XSpriteCanvas_ff8b0df1
    from ..util.x_modify_listener import XModifyListener as XModifyListener_d5c60ccc

class XSlideShowView(XInterface_8f010a43):
    """
    View interface to display slide show presentations on.
    
    This interface provides the necessary methods to enable an XSlideShow interface to display a presentation. The slide show can be displayed simultaneously on multiple views
    
    **since**
    
        OOo 2.4

    See Also:
        `API XSlideShowView <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowView.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.presentation.XSlideShowView']

    def addMouseListener(self, xListener: 'XMouseListener_bc1d0bfb') -> None:
        """
        Add a mouse listener to the view.
        
        This method registers a listener with the view, which will get called every time the mouse is clicked on the view.
        """
    def addMouseMotionListener(self, xListener: 'XMouseMotionListener_c6a0e71') -> None:
        """
        Add a mouse motion listener to the view.
        
        This method registers a listener with the view, which will get called every time the mouse is moved on the view.
        """
    def addPaintListener(self, xListener: 'XPaintListener_bb6d0bee') -> None:
        """
        Add a listener to get notified when this view needs a repaint.
        
        This method registers a listener with the view, which will get called every time the view needs an update of their screen representation.
        """
    def addTransformationChangedListener(self, xListener: 'XModifyListener_d5c60ccc') -> None:
        """
        Add a listener to get notified when the transformation matrix changes.
        
        This method registers a listener with the view, which will get called every time the transformation matrix changes.
        """
    def clear(self) -> None:
        """
        This method clears the whole view area.
        
        The slide show uses this method to fully erase the view content. Since the slide show has no notion of view size, this is the only reliable way to wholly clear the view.
        """
    def getCanvas(self) -> 'XSpriteCanvas_ff8b0df1':
        """
        Get view canvas.
        
        This method gets the underlying XCanvas to display on this view.
        """
    def getCanvasArea(self) -> 'Rectangle_84b109e9':
        """
        Get rectangle defining area inside of canvas device which this slide show view uses.
        """
    def getTransformation(self) -> 'AffineMatrix2D_ff040da8':
        """
        Query the current transformation matrix for this view.
        
        This method returns the transformation matrix of the view. When notified via the transformation change listener, the show will be displayed using the new transformation.
        """
    def getTranslationOffset(self) -> 'IntegerSize2D_f2690d53':
        """
        Query the current translation offset used to fill the physical screen while keeping aspect ratio.
        
        This method returns the translation offset of the view of the view.
        """
    def removeMouseListener(self, xListener: 'XMouseListener_bc1d0bfb') -> None:
        """
        Revoke a previously registered mouse listener.
        """
    def removeMouseMotionListener(self, xListener: 'XMouseMotionListener_c6a0e71') -> None:
        """
        Revoke a previously registered mouse move listener.
        """
    def removePaintListener(self, xListener: 'XPaintListener_bb6d0bee') -> None:
        """
        Revoke a previously registered paint listener.
        """
    def removeTransformationChangedListener(self, xListener: 'XModifyListener_d5c60ccc') -> None:
        """
        Revoke a previously registered transformation matrix change listener.
        """
    def setMouseCursor(self, nPointerShape: int) -> None:
        """
        Change the mouse cursor currently in effect.
        
        This method changes the mouse cursor currently in effect, for this view.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.beans
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .get_direct_property_tolerant_result import GetDirectPropertyTolerantResult as GetDirectPropertyTolerantResult_e91c13b9
    from .get_property_tolerant_result import GetPropertyTolerantResult as GetPropertyTolerantResult_7c4e115e
    from .set_property_tolerant_failed import SetPropertyTolerantFailed as SetPropertyTolerantFailed_7cbd1130

class XTolerantMultiPropertySet(XInterface_8f010a43):
    """
    provides access to multiple iformation of a set of properties with a single call.
    
    The speciality of this interface is that none of the functions will throw the usual exceptions associated with setting and retrieving of property values. Instead the data for the failures is collected and returned.
    
    Note: There is no support for property change listeners in this interface.

    See Also:
        `API XTolerantMultiPropertySet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XTolerantMultiPropertySet.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.beans.XTolerantMultiPropertySet']

    def getDirectPropertyValuesTolerant(self, aPropertyNames: 'typing.Tuple[str, ...]') -> 'typing.Tuple[GetDirectPropertyTolerantResult_e91c13b9, ...]':
        """
        retrieve only those values of the specified properties which are direct values.
        
        Since the count of returned elements may be different from the number of supplied property names the returned elements will also state the name of the property.
        
        If the names are not sorted the behaviour of the method is undefined!
        """
    def getPropertyValuesTolerant(self, aPropertyNames: 'typing.Tuple[str, ...]') -> 'typing.Tuple[GetPropertyTolerantResult_7c4e115e, ...]':
        """
        retrieve the values of the specified properties
        
        The count and order of the values in the returned sequence will be the same as the order of the names in the argument.
        
        If the names are not sorted the behaviour of the method is undefined!
        """
    def setPropertyValuesTolerant(self, aPropertyNames: 'typing.Tuple[str, ...]', aValues: 'typing.Tuple[object, ...]') -> 'typing.Tuple[SetPropertyTolerantFailed_7cbd1130, ...]':
        """
        sets the values to the properties with the specified names.
        
        If the names are not sorted the behaviour of the method is undefined!
        
        Otherwise for every property value that could not successfully be set an entry of the com.sun.star.beans.SetPropertyTolerantFailed will be present in this sequence. The order of the properties is also alphabetically ascending.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from typing_extensions import Literal
"""
Const

The constant set contains possible aspects for an embedded object.

This constant set provides a set of values that can be used to specify the kind of object view. It can be used for example by container to request view representation of a certain kind from XEmbeddedObject.

The first 32 bits are reserved for MS OLE aspects.

See Also:
    `API Aspects <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1Aspects.html>`_
"""
MSOLE_CONTENT: Literal[1]
"""
specifies view of the object to be displayed as an embedded object inside a container.
"""
MSOLE_THUMBNAIL: Literal[2]
"""
specifies view of the object to be displayed in a browsing tool.
"""
MSOLE_ICON: Literal[4]
"""
specifies view of the object when object is represented by Icon.
"""
MSOLE_DOCPRINT: Literal[8]
"""
specifies view of the object for print preview.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
from typing_extensions import Literal


class BarCodeErrorCorrection(object):
    """
    Const

    These constants identify the type of Error Correction for a Bar Code.
    
    The Error Correction for a Bar code is a measure that helps a Bar code to recover, if it is destroyed.
    
    Level L (Low) 7% of codewords can be restored. Level M (Medium) 15% of codewords can be restored. Level Q (Quartile) 25% of codewords can be restored. Level H (High) 30% of codewords can be restored.
    
    More Info - here
    
    **since**
    
        LibreOffice 7.3

    See Also:
        `API BarCodeErrorCorrection <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1BarCodeErrorCorrection.html>`_
    """
    LOW: Literal[1]
    MEDIUM: Literal[2]
    QUARTILE: Literal[3]
    HIGH: Literal[4]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.3
from typing_extensions import Literal
from .search_options import SearchOptions as SearchOptions_bd140c08
from .search_algorithms import SearchAlgorithms as SearchAlgorithms_e2c00d36
from ..lang.locale import Locale as Locale_70d308fa
import typing


class SearchOptions2(SearchOptions_bd140c08):
    """
    Struct Class

    This augments com.sun.star.util.SearchOptions to be able to specify additional search algorithms for use with com.sun.star.util.XTextSearch2.
    
    **since**
    
        LibreOffice 5.2

    See Also:
        `API SearchOptions2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1SearchOptions2.html>`_
    """
    typeName: Literal['com.sun.star.util.SearchOptions2']

    def __init__(self, algorithmType: typing.Optional[SearchAlgorithms_e2c00d36] = ..., searchFlag: typing.Optional[int] = ..., searchString: typing.Optional[str] = ..., replaceString: typing.Optional[str] = ..., Locale: typing.Optional[Locale_70d308fa] = ..., changedChars: typing.Optional[int] = ..., deletedChars: typing.Optional[int] = ..., insertedChars: typing.Optional[int] = ..., transliterateFlags: typing.Optional[int] = ..., AlgorithmType2: typing.Optional[int] = ..., WildcardEscapeCharacter: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            algorithmType (SearchAlgorithms, optional): algorithmType value.
            searchFlag (int, optional): searchFlag value.
            searchString (str, optional): searchString value.
            replaceString (str, optional): replaceString value.
            Locale (Locale, optional): Locale value.
            changedChars (int, optional): changedChars value.
            deletedChars (int, optional): deletedChars value.
            insertedChars (int, optional): insertedChars value.
            transliterateFlags (int, optional): transliterateFlags value.
            AlgorithmType2 (int, optional): AlgorithmType2 value.
            WildcardEscapeCharacter (int, optional): WildcardEscapeCharacter value.
        """


    @property
    def AlgorithmType2(self) -> int:
        """
        Search type, one of com.sun.star.util.SearchAlgorithms2 constants.
        
        This is preferred over the content of the SearchAlgorithms SearchOptions.algorithmType enum field.
        """


    @property
    def WildcardEscapeCharacter(self) -> int:
        """
        The escape character to be used with a com.sun.star.util.SearchAlgorithms2.WILDCARD search.
        
        A Unicode character, if not 0 escapes the special meaning of a question mark, asterisk or escape character that follows immediately after the escape character. If 0 defines no escape character is used.
        
        Common values are '\\' (U+005C REVERSE SOLIDUS) aka backslash in text processing context, or '~' (U+007E TILDE) in spreadsheet processing context.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from .accessible_list import AccessibleList as AccessibleList_bb240bde

class AccessibleListBoxList(AccessibleList_bb240bde):
    """
    Service Class

    Accessible list box lists are used by list boxes as container for the list items.
    
    In addition of the simple container functionality of the AccessibleList service the com.sun.star.accessibility.XAccessibleSelection interface is supported.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleListBoxList <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1AccessibleListBoxList.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
import typing
from .result_set import ResultSet as ResultSet_847b09ec
from .x_completed_execution import XCompletedExecution as XCompletedExecution_fb8c0dea
from .x_parameters_supplier import XParametersSupplier as XParametersSupplier_fc7c0e01
from .x_result_set_access import XResultSetAccess as XResultSetAccess_d34d0c96
from .x_row_set_approve_broadcaster import XRowSetApproveBroadcaster as XRowSetApproveBroadcaster_56601044
from ..sdbc.row_set import RowSet as RowSet_70fd0908
from ..sdbc.x_result_set_update import XResultSetUpdate as XResultSetUpdate_e0fb0d0a
from ..sdbcx.x_delete_rows import XDeleteRows as XDeleteRows_af5c0b72
if typing.TYPE_CHECKING:
    from ..sdbc.x_connection import XConnection as XConnection_a36a0b0c

class RowSet(ResultSet_847b09ec, RowSet_70fd0908, XCompletedExecution_fb8c0dea, XParametersSupplier_fc7c0e01, XResultSetAccess_d34d0c96, XRowSetApproveBroadcaster_56601044, XResultSetUpdate_e0fb0d0a, XDeleteRows_af5c0b72):
    """
    Service Class

    is a client side RowSet, which use retrieves is data based on a database table, a query or a SQL command or by a row set reader, who mustn't support SQL.
    
    The connection of the row set is typically a named DataSource or a DataAccess component or a previous instantiated connection.
    
    Depending on the com.sun.star.sdbc.ResultSetConcurrency , the RowSet caches all data or uses an optimized way for retrieving the data, such as, refetching rows by their keys or if provided, by their bookmarks.
    
    In addition, it provides events for RowSet navigation and RowSet modifications to approve the actions and to react on them.
    
    A row set is able to be operated in various ways, and additionally it notifies various changes in its state. Clients of this service can rely on a fixed order of notifications, depending on how they operate on the component.
    The following describes the general order of all possible notifications which you can encounter when working with a row set:
    
    The following matrix shows the notifications which apply to the different operations:
    
    Via com.sun.star.sdbc.XResultSetUpdate.deleteRow(), you can delete the current row of a RowSet. This deleted row then doesn't vanish immediately, but is still present, and subsequent calls to com.sun.star.sdbc.XResultSet.rowDeleted() will return TRUE. The deleted row \"vanishes\" from the RowSet as soon as the cursor is moved away from it.
    As a consequence, the behavior of several other methods is affected:

    See Also:
        `API RowSet <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1RowSet.html>`_
    """
    @property
    def ActiveCommand(self) -> str:
        """
        is the command which is currently used.
        """
    @property
    def ActiveConnection(self) -> 'XConnection_a36a0b0c':
        """
        is the connection generated by a DataSource or by a URL.
        
        It could also be set from outside. When set from outside the RowSet is not responsible for the closing of the connection.
        """
    @property
    def ApplyFilter(self) -> bool:
        """
        indicates whether the filter should be applied or not, default is FALSE.
        """
    @property
    def Command(self) -> str:
        """
        is the command which should be executed, the type of command depends on the CommandType.
        
        In case of a CommandType of CommandType.COMMAND, means in case the Command specifies an SQL statement, the inherited com.sun.star.sdbc.RowSet.EscapeProcessing becomes relevant:
        It then can be to used to specify whether the SQL statement should be analyzed on the client side before sending it to the database server.
        The default value for com.sun.star.sdbc.RowSet.EscapeProcessing is TRUE. By switching it to FALSE, you can pass backend-specific SQL statements, which are not standard SQL, to your database.
        """
    @property
    def CommandType(self) -> int:
        """
        is the type of the command.
        """
    @property
    def DataSourceName(self) -> str:
        """
        is the name of the datasource to use, this could be a named datasource or the URL of a data access component.
        """
    @property
    def Filter(self) -> str:
        """
        additional filter for a row set.
        """
    @property
    def GroupBy(self) -> str:
        """
        additional group by for the row set
        """
    @property
    def HavingClause(self) -> str:
        """
        additional having clause for the row set
        """
    @property
    def IgnoreResult(self) -> bool:
        """
        indicates whether all results should be discarded or not.
        """
    @property
    def IsModified(self) -> bool:
        """
        indicates that the current row is modified.
        """
    @property
    def IsNew(self) -> bool:
        """
        indicates that the current row is going to be inserted to the database.
        """
    @property
    def IsRowCountFinal(self) -> bool:
        """
        indicates that all rows of the row set have been counted.
        """
    @property
    def Order(self) -> str:
        """
        is an additional sort order definition for a row set.
        """
    @property
    def Privileges(self) -> int:
        """
        indicates the privileges for insert, update, and delete.
        """
    @property
    def RowCount(self) -> int:
        """
        contains the number of rows accessed in the data source.
        """
    @property
    def UpdateCatalogName(self) -> str:
        """
        is the name of the table catalog
        """
    @property
    def UpdateSchemaName(self) -> str:
        """
        is the name of the table schema.
        """
    @property
    def UpdateTableName(self) -> str:
        """
        is the name of the table which should be updated, this is usually used for queries which relate to more than one table.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbcx
from typing_extensions import Literal


class Privilege(object):
    """
    Const

    defines a list of flags (bitmaps) which determines the access rights of a user or a user group.
    
    This list may grow in the future.

    See Also:
        `API Privilege <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdbcx_1_1Privilege.html>`_
    """
    SELECT: Literal[1]
    """
    indicates that a user is allowed to read the data.
    """
    INSERT: Literal[2]
    """
    indicates that a user is allowed to insert new data.
    """
    UPDATE: Literal[4]
    """
    indicates that a user is allowed to update data.
    """
    DELETE: Literal[8]
    """
    indicates that a user is allowed to delete data.
    """
    READ: Literal[16]
    """
    indicates that a user is allowed to read the structure of a definition object.
    """
    CREATE: Literal[32]
    """
    indicates that a user is allowed to create a definition object.
    """
    ALTER: Literal[64]
    """
    indicates that a user is allowed to alter an existing object.
    """
    REFERENCE: Literal[128]
    """
    indicates that a user is allowed to set foreign keys for a table.
    """
    DROP: Literal[256]
    """
    indicates that a user is allowed to drop a definition object.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.inspection
from typing_extensions import Literal
import typing
from ..frame.x_controller import XController as XController_b00e0b8f
from ..frame.x_dispatch_provider import XDispatchProvider as XDispatchProvider_fc690de6
if typing.TYPE_CHECKING:
    from .x_object_inspector_model import XObjectInspectorModel as XObjectInspectorModel_9077119b
    from .x_object_inspector_ui import XObjectInspectorUI as XObjectInspectorUI_5ccd1048
    from ..uno.x_interface import XInterface as XInterface_8f010a43

class XObjectInspector(XController_b00e0b8f, XDispatchProvider_fc690de6):
    """
    describes the main interface of an ObjectInspector.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XObjectInspector <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspector.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.inspection.XObjectInspector']

    def inspect(self, Objects: 'typing.Tuple[XInterface_8f010a43, ...]') -> None:
        """
        inspects a new collection of one or more objects.
        
        If the sequence is empty, the UI of the ObjectInspector will be cleared.
        
        If the sequence contains more than one object, the XObjectInspector will create a complete set of property handlers (as indicated by XObjectInspectorModel.HandlerFactories) for every of the objects, and compose their output.

        Raises:
            com.sun.star.util.VetoException: ``VetoException``
        """
    @property
    def InspectorModel(self) -> 'XObjectInspectorModel_9077119b':
        """
        provides access to the current model of the inspector
        
        The model is mainly responsible for providing the property handlers. Additionally, it can provide user interface names and help URLs for property categories.
        
        Note that there are two ways of setting or retrieving the current model: You can either use com.sun.star.frame.XModel.setModel(), or, if you do not want or need to implement the full-blown com.sun.star.frame.XModel interface, you can use this property directly. Both approaches are semantically equivalent.
        
        If a new model is set at the inspector, the complete UI will be rebuilt to reflect the change, using the new property handlers provided by the new model.
        """

    @property
    def InspectorUI(self) -> 'XObjectInspectorUI_5ccd1048':
        """
        provides access to the user interface of the object inspector.
        
        This interface can be used to access and manipulate various aspects of the user interface. For instance, you can enable and disable certain property controls (or parts thereof), or register observers for all property controls.
        
        **since**
        
            OOo 2.2
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_session_manager_listener import XSessionManagerListener as XSessionManagerListener_582d1050

class XSessionManagerClient(XInterface_8f010a43):
    """
    Connect to a session manager to get information about pending desktop shutdown.

    See Also:
        `API XSessionManagerClient <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XSessionManagerClient.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XSessionManagerClient']

    def addSessionManagerListener(self, xListener: 'XSessionManagerListener_582d1050') -> None:
        """
        addSessionManagerListener registers a listener for session management events
        """
    def cancelShutdown(self) -> bool:
        """
        Call cancelShutdown to try to cancel a desktop shutdown in progress.
        """
    def interactionDone(self, xListener: 'XSessionManagerListener_582d1050') -> None:
        """
        interactionDone is called when a listener has finished user interaction
        """
    def queryInteraction(self, xListener: 'XSessionManagerListener_582d1050') -> None:
        """
        queryInteraction issues a request for a user interaction slot from the session manager
        """
    def removeSessionManagerListener(self, xListener: 'XSessionManagerListener_582d1050') -> None:
        """
        removeSessionManagerListener deregisters a listener for session events
        """
    def saveDone(self, xListener: 'XSessionManagerListener_582d1050') -> None:
        """
        saveDone signals that a listener has processed a save request
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from typing_extensions import Literal
from .locale_data_item import LocaleDataItem as LocaleDataItem_beff0ba1
import typing


class LocaleDataItem2(LocaleDataItem_beff0ba1):
    """
    Struct Class

    Locale specific data, derived from LocaleDataItem adding an alternative input decimal separator.
    
    **since**
    
        LibreOffice 6.0

    See Also:
        `API LocaleDataItem2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1LocaleDataItem2.html>`_
    """
    typeName: Literal['com.sun.star.i18n.LocaleDataItem2']

    def __init__(self, unoID: typing.Optional[str] = ..., dateSeparator: typing.Optional[str] = ..., thousandSeparator: typing.Optional[str] = ..., decimalSeparator: typing.Optional[str] = ..., timeSeparator: typing.Optional[str] = ..., time100SecSeparator: typing.Optional[str] = ..., listSeparator: typing.Optional[str] = ..., quotationStart: typing.Optional[str] = ..., quotationEnd: typing.Optional[str] = ..., doubleQuotationStart: typing.Optional[str] = ..., doubleQuotationEnd: typing.Optional[str] = ..., timeAM: typing.Optional[str] = ..., timePM: typing.Optional[str] = ..., measurementSystem: typing.Optional[str] = ..., LongDateDayOfWeekSeparator: typing.Optional[str] = ..., LongDateDaySeparator: typing.Optional[str] = ..., LongDateMonthSeparator: typing.Optional[str] = ..., LongDateYearSeparator: typing.Optional[str] = ..., decimalSeparatorAlternative: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            unoID (str, optional): unoID value.
            dateSeparator (str, optional): dateSeparator value.
            thousandSeparator (str, optional): thousandSeparator value.
            decimalSeparator (str, optional): decimalSeparator value.
            timeSeparator (str, optional): timeSeparator value.
            time100SecSeparator (str, optional): time100SecSeparator value.
            listSeparator (str, optional): listSeparator value.
            quotationStart (str, optional): quotationStart value.
            quotationEnd (str, optional): quotationEnd value.
            doubleQuotationStart (str, optional): doubleQuotationStart value.
            doubleQuotationEnd (str, optional): doubleQuotationEnd value.
            timeAM (str, optional): timeAM value.
            timePM (str, optional): timePM value.
            measurementSystem (str, optional): measurementSystem value.
            LongDateDayOfWeekSeparator (str, optional): LongDateDayOfWeekSeparator value.
            LongDateDaySeparator (str, optional): LongDateDaySeparator value.
            LongDateMonthSeparator (str, optional): LongDateMonthSeparator value.
            LongDateYearSeparator (str, optional): LongDateYearSeparator value.
            decimalSeparatorAlternative (str, optional): decimalSeparatorAlternative value.
        """


    @property
    def decimalSeparatorAlternative(self) -> str:
        """
        Alternative input decimal separator, for example, \".\" if the regular locale dependent separator usually is not present on keyboards used with that locale.
        
        This separator is optional, an empty string denotes no alternative decimal separator shall be used.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt.grid
from typing_extensions import Literal
import typing
from .x_grid_data_model import XGridDataModel as XGridDataModel_f8b20d71
if typing.TYPE_CHECKING:
    from .x_grid_data_listener import XGridDataListener as XGridDataListener_23f10ec6

class XMutableGridDataModel(XGridDataModel_f8b20d71):
    """
    allows to modify the data represented by a XGridDataModel

    See Also:
        `API XMutableGridDataModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XMutableGridDataModel.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.grid.XMutableGridDataModel']

    def addGridDataListener(self, Listener: 'XGridDataListener_23f10ec6') -> None:
        """
        registers listener to be notified of data changes in the model
        """
    def addRow(self, Heading: object, Data: 'typing.Tuple[object, ...]') -> None:
        """
        appends a row to the model.
        """
    def addRows(self, Headings: 'typing.Tuple[object, ...]', Data: 'typing.Tuple[typing.Tuple[object, ...], ...]') -> None:
        """
        appends multiple rows of data to the model.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def insertRow(self, Index: int, Heading: object, Data: 'typing.Tuple[object, ...]') -> None:
        """
        inserts a row into the set of data rows

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def insertRows(self, Index: int, Headings: 'typing.Tuple[object, ...]', Data: 'typing.Tuple[typing.Tuple[object, ...], ...]') -> None:
        """
        inserts multiple rows of data into the model.

        Raises:
            : ````
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def removeAllRows(self) -> None:
        """
        Removes all rows from the model.
        """
    def removeGridDataListener(self, Listener: 'XGridDataListener_23f10ec6') -> None:
        """
        revokes a listener which was previously registered via addGridDataListener()
        """
    def removeRow(self, RowIndex: int) -> None:
        """
        removes a row of data from the model

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def updateCellData(self, ColumnIndex: int, RowIndex: int, Value: object) -> None:
        """
        updates the content of the given cell

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def updateCellToolTip(self, ColumnIndex: int, RowIndex: int, Value: object) -> None:
        """
        updates the tooltip to be displayed for a given cell

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def updateRowData(self, ColumnIndexes: 'typing.Tuple[int, ...]', RowIndex: int, Values: 'typing.Tuple[object, ...]') -> None:
        """
        updates the content of a given row.
        
        The change in the data model will be notified to registered listeners via XGridDataListener.dataChanged(). The GridDataEvent.FirstColumn and GridDataEvent.LastColumn will denote the smallest respectively largest column index from ColumnIndexes.

        Raises:
            : ````
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def updateRowHeading(self, RowIndex: int, Heading: object) -> None:
        """
        sets a new title for a given row.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def updateRowToolTip(self, RowIndex: int, Value: object) -> None:
        """
        updates the tooltip for all cells of a given row
        
        Effectively this method is a shortcut for calling updateCellToolTip() multiple times in a row, for all cells of a given row.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
from enum import Enum

class CurveStyle(Enum):
    """
    Enum

    

    See Also:
        `API CurveStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart2.html#a6eee32347565343ce84b84adb82da419>`_
    """

    B_SPLINES: 'uno.Enum'
    """
    Data points are connected via a parametric, interpolating B-spline curve.
    """
    CUBIC_SPLINES: 'uno.Enum'
    """
    Data points are connected via a smoothed cubic spline curve.
    
    The data points themselves are part of to the curve.
    """
    LINES: 'uno.Enum'
    """
    Lines between data points are not smoothed.
    """
    NURBS: 'uno.Enum'
    """
    Non-uniform rational b-splines.
    """
    STEP_CENTER_X: 'uno.Enum'
    """
    Data points are connected via a 3-segmented stepped line.
    
    The lines is horizontal till the center of the X values.
    """
    STEP_CENTER_Y: 'uno.Enum'
    """
    Data points are connected via a 3-segmented stepped line.
    
    The lines is horizontal at the center of the Y values.
    """
    STEP_END: 'uno.Enum'
    """
    Data points are connected via a 2-segmented stepped line.
    
    The line ends horizontally.
    """
    STEP_START: 'uno.Enum'
    """
    Data points are connected via a 2-segmented stepped line.
    
    The line starts horizontally.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class DataPilotFieldReference(object):
    """
    Struct Class

    controls how a data pilot field's results are shown in relation to a selected reference result.

    See Also:
        `API DataPilotFieldReference <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReference.html>`_
    """
    typeName: Literal['com.sun.star.sheet.DataPilotFieldReference']

    def __init__(self, ReferenceType: typing.Optional[int] = ..., ReferenceField: typing.Optional[str] = ..., ReferenceItemType: typing.Optional[int] = ..., ReferenceItemName: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            ReferenceType (int, optional): ReferenceType value.
            ReferenceField (str, optional): ReferenceField value.
            ReferenceItemType (int, optional): ReferenceItemType value.
            ReferenceItemName (str, optional): ReferenceItemName value.
        """


    @property
    def ReferenceType(self) -> int:
        """
        contains the type of the reference.
        """


    @property
    def ReferenceField(self) -> str:
        """
        contains the reference field
        """


    @property
    def ReferenceItemType(self) -> int:
        """
        selects between a named reference item and using the previous or next item for each item from the reference field.
        """


    @property
    def ReferenceItemName(self) -> str:
        """
        contains the name of the reference item, when the DataPilotFieldReference.ReferenceItemType is NAMED otherwise is empty
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from .x_style_change_listener import XStyleChangeListener as XStyleChangeListener_ad50e49
    from ..util.color import Color as Color_68e908c5

class XStyleSettings(ABC):
    """
    provides access to certain style settings within an OpenOffice.org component, such as a window, or within OpenOffice.org as a whole.
    
    Note that there are constraints for those settings. For instance, if controls are drawn with the native widget framework, i.e. in the desktop theme's look, then they won't necessarily respect all their style settings, because those have a lesser priority than the native look.
    
    On the other hand, some settings are respected only when rendering the controls in the native desktop/theme look. For instance, without native theming, buttons do not support a \"roll over\" mode, i.e., they're painted the same way, no matter if they mouse hovers over them or not. But with native theming, this changes, as here the general button look is drawn by the system's theming engine, while the text is drawn by OpenOffice.org. In this case, the button respects the ButtonRolloverTextColor when painting its text.

    See Also:
        `API XStyleSettings <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XStyleSettings.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XStyleSettings']

    def addStyleChangeListener(self, Listener: 'XStyleChangeListener_ad50e49') -> None:
        """
        registers a listener to be notified when the style settings change
        """
    def removeStyleChangeListener(self, Listener: 'XStyleChangeListener_ad50e49') -> None:
        """
        registers a listener to be notified when the style settings change
        """
    @property
    def ActiveBorderColor(self) -> 'Color_68e908c5':
        """
        specifies the color of the border of active windows
        """

    @property
    def ActiveColor(self) -> 'Color_68e908c5':
        """
        """

    @property
    def ActiveTabColor(self) -> 'Color_68e908c5':
        """
        specifies the color of the active tab of a tab control
        """

    @property
    def ActiveTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color for active UI components
        """

    @property
    def ApplicationFont(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the application font
        """

    @property
    def ButtonRolloverTextColor(self) -> 'Color_68e908c5':
        """
        specifies the color to use for text on buttons which are hovered with the mouse
        """

    @property
    def ButtonTextColor(self) -> 'Color_68e908c5':
        """
        specifies the color to use for text on buttons
        """

    @property
    def CheckedColor(self) -> 'Color_68e908c5':
        """
        """

    @property
    def DarkShadowColor(self) -> 'Color_68e908c5':
        """
        specifies the dark portion of the shadow to use for UI elements
        """

    @property
    def DeactiveBorderColor(self) -> 'Color_68e908c5':
        """
        specifies the color of the border of inactive windows
        """

    @property
    def DeactiveColor(self) -> 'Color_68e908c5':
        """
        """

    @property
    def DeactiveTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color for inactive UI components
        """

    @property
    def DialogColor(self) -> 'Color_68e908c5':
        """
        specifies the background color of dialogs
        """

    @property
    def DialogTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color of dialogs
        """

    @property
    def DisableColor(self) -> 'Color_68e908c5':
        """
        specifies the text color for disabled UI elements
        """

    @property
    def FaceColor(self) -> 'Color_68e908c5':
        """
        """

    @property
    def FaceGradientColor(self) -> 'Color_68e908c5':
        """
        """

    @property
    def FieldColor(self) -> 'Color_68e908c5':
        """
        specifies the background color for dialog input controls
        """

    @property
    def FieldFont(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font for dialog input controls
        """

    @property
    def FieldRolloverTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color for dialog input controls which are hovered with the mouse
        """

    @property
    def FieldTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color for dialog input controls
        """

    @property
    def FloatTitleFont(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font to use the title of floating windows
        """

    @property
    def GroupFont(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font for dialog elements used for grouping other elements
        """

    @property
    def GroupTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color for dialog elements used for grouping other elements
        """

    @property
    def HelpColor(self) -> 'Color_68e908c5':
        """
        specifies the background color for dialog elements displaying help content
        """

    @property
    def HelpFont(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the help font
        """

    @property
    def HelpTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color for dialog elements displaying help content
        """

    @property
    def HighContrastMode(self) -> bool:
        """
        controls whether the an UI component should use a high-contrast mode
        """

    @property
    def HighlightColor(self) -> 'Color_68e908c5':
        """
        specifies the background color for UI elements which are highlighted
        """

    @property
    def HighlightTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color for UI elements which are highlighted
        """

    @property
    def InactiveTabColor(self) -> 'Color_68e908c5':
        """
        specifies the color of inactive tabs of a tab control
        """

    @property
    def LabelFont(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font for label controls
        """

    @property
    def LabelTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color of label elements in dialogs
        """

    @property
    def LightColor(self) -> 'Color_68e908c5':
        """
        """

    @property
    def MenuBarColor(self) -> 'Color_68e908c5':
        """
        specifies the background color of menu bars
        """

    @property
    def MenuBarTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color of menu bars
        """

    @property
    def MenuBorderColor(self) -> 'Color_68e908c5':
        """
        specifies the border color of menus
        """

    @property
    def MenuColor(self) -> 'Color_68e908c5':
        """
        """

    @property
    def MenuFont(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font to use for menus
        """

    @property
    def MenuHighlightColor(self) -> 'Color_68e908c5':
        """
        specifies the background color of highlighted menu items
        """

    @property
    def MenuHighlightTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color of highlighted menu items
        """

    @property
    def MenuTextColor(self) -> 'Color_68e908c5':
        """
        """

    @property
    def MonoColor(self) -> 'Color_68e908c5':
        """
        specifies the color to use for monochrome control elements such as flat borders of controls
        """

    @property
    def PushButtonFont(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font of push buttons
        """

    @property
    def RadioCheckFont(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font of radio buttons and check boxes
        """

    @property
    def RadioCheckTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color of radio buttons and check boxes
        """

    @property
    def SeparatorColor(self) -> 'Color_68e908c5':
        """
        specifies the color of separators between UI elements
        """

    @property
    def ShadowColor(self) -> 'Color_68e908c5':
        """
        specifies the color to use for UI elements
        """

    @property
    def TitleFont(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font to use for window titles
        """

    @property
    def ToolFont(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font to use for tool elements
        """

    @property
    def WindowColor(self) -> 'Color_68e908c5':
        """
        specifies the background color to use for non-dialog windows
        """

    @property
    def WindowTextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color to use for non-dialog windows
        """

    @property
    def WorkspaceColor(self) -> 'Color_68e908c5':
        """
        specifies the background color to use for document workspaces
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.xml.crypto.sax
from typing_extensions import Literal
import typing
from ....uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...sax.x_document_handler import XDocumentHandler as XDocumentHandler_9b90e28
    from ...wrapper.xxml_element_wrapper import XXMLElementWrapper as XXMLElementWrapper_66c0107c

class XSAXEventKeeper(XInterface_8f010a43):
    """
    Interface of SAX Event Keeper.
    
    This interface is used to manipulate element marks in a SAX event stream.
    
    There are two kinds of element mark, one is element collector, which is used to collect a particular element from the SAX event stream; the other is blocker, which is used to block the SAX event stream.

    See Also:
        `API XSAXEventKeeper <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XSAXEventKeeper.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.crypto.sax.XSAXEventKeeper']

    def addBlocker(self) -> int:
        """
        Adds a new blocker on the next element in the SAX event stream.
        
        No SAX event starting from the next element will be forwarded until this blocker is removed.
        """
    def addElementCollector(self) -> int:
        """
        Adds a new element collector on the next element in the SAX event stream.
        """
    def getCurrentBlockingNode(self) -> 'XXMLElementWrapper_66c0107c':
        """
        Gets the element which current blocking happens.
        
        This element is the working element of the first blocker in tree order.
        """
    def getElement(self, id: int) -> 'XXMLElementWrapper_66c0107c':
        """
        Gets the element of an element mark.
        """
    def isBlocking(self) -> bool:
        """
        Checks whether the SAX event stream is blocking.
        """
    def printBufferNodeTree(self) -> str:
        """
        Prints information about all buffered elements.
        """
    def removeBlocker(self, id: int) -> None:
        """
        Removes a blocker.
        """
    def removeElementCollector(self, id: int) -> None:
        """
        Removes an element collector.
        """
    def setElement(self, id: int, aElement: 'XXMLElementWrapper_66c0107c') -> None:
        """
        Sets the element of an element mark.
        
        When an element is replaced outside of this interface, then uses this method can restore the link between an element mark and its working element.
        """
    def setNextHandler(self, nextHandler: 'XDocumentHandler_9b90e28') -> 'XDocumentHandler_9b90e28':
        """
        Sets the next document handler in the SAX chain.
        
        This handler will receive SAX events forwarded by the SAXEventKeeper.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .direction3_d import Direction3D as Direction3D_c9370c0c
    from .enhanced_custom_shape_parameter_pair import EnhancedCustomShapeParameterPair as EnhancedCustomShapeParameterPair_262914a3
    from .position3_d import Position3D as Position3D_bddc0bc0
    from .projection_mode import ProjectionMode as ProjectionMode_f1ff0d96
    from .shade_mode import ShadeMode as ShadeMode_b0c60b5e

class EnhancedCustomShapeExtrusion(ABC):
    """
    Service Class

    This service may be represented by a com.sun.star.beans.PropertyValue [].

    See Also:
        `API EnhancedCustomShapeExtrusion <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeExtrusion.html>`_
    """
    @property
    def Brightness(self) -> float:
        """
        This attribute specifies the brightness of a scene in percent.
        """
    @property
    def Depth(self) -> 'EnhancedCustomShapeParameterPair_262914a3':
        """
        The first value of EnhancedCustomShapeParameterPair specifies the depth of the extrusion in 1/100 mm.
        
        The second value (0.0 to 1.0) specifies the fraction of the extrusion that lies before the shape, a value of 0 is default.
        """
    @property
    def Diffusion(self) -> float:
        """
        This attribute specifies the amount of diffusion reflected by the shape in percent.
        """
    @property
    def Extrusion(self) -> bool:
        """
        This property specifies if extrusion is displayed.
        
        The default for this property is \"false\"
        """
    @property
    def ExtrusionColor(self) -> bool:
        """
        This attribute specifies if the \"SecondFillColor\" is used as extrusion color.
        """
    @property
    def FirstLightDirection(self) -> 'Direction3D_c9370c0c':
        """
        Specifies the direction of the first light.
        """
    @property
    def FirstLightHarsh(self) -> bool:
        """
        Specifies if the primary light is harsh.
        """
    @property
    def FirstLightLevel(self) -> float:
        """
        Specifies the intensity for the first light in percent.
        """
    @property
    def LightFace(self) -> bool:
        """
        Specifies if the front face of the extrusion responds to lightning changes.
        """
    @property
    def Metal(self) -> bool:
        """
        Specifies if the surface of the extrusion object looks like metal.
        """
    @property
    def NumberOfLineSegments(self) -> int:
        """
        Specifies the number of line segments that should be used to display curved surfaces.
        
        The higher the number the more line segments are used.
        """
    @property
    def Origin(self) -> 'EnhancedCustomShapeParameterPair_262914a3':
        """
        This attribute specifies the origin within the bounding box of the shape in terms of the shape size fractions.
        """
    @property
    def ProjectionMode(self) -> 'ProjectionMode_f1ff0d96':
        """
        This property defines the projection mode.
        """
    @property
    def RotateAngle(self) -> 'EnhancedCustomShapeParameterPair_262914a3':
        """
        This attributes specifies the rotation angle about the x-axis in grad.
        
        The order of rotation is: z-axis, y-axis and then x-axis. The z-axis is specified by the draw:rotate-angle.
        """
    @property
    def RotationCenter(self) -> 'Direction3D_c9370c0c':
        """
        This attribute specifies the position of the rotate center in terms of shape size fractions, if the property is omitted, then the geometrical center of the shape is used (this is the default).
        """
    @property
    def SecondLightDirection(self) -> 'Direction3D_c9370c0c':
        """
        Specifies the direction of the second light.
        """
    @property
    def SecondLightHarsh(self) -> bool:
        """
        Specifies if the secondary light is harsh.
        """
    @property
    def SecondLightLevel(self) -> float:
        """
        Specifies the intensity for the second light in percent.
        """
    @property
    def ShadeMode(self) -> 'ShadeMode_b0c60b5e':
        """
        This property defines the shade mode.
        """
    @property
    def Shininess(self) -> float:
        """
        The draw:extrusion-shininess specifies the shininess of a mirror in percent.
        """
    @property
    def Skew(self) -> 'EnhancedCustomShapeParameterPair_262914a3':
        """
        The first value of the draw:extrusion-skew attribute specifies the skew amount of an extrusion in percent.
        
        The second parameter specifies the skew-angle. Skew settings are only applied if the attribute ProjectionMode is ProjectionMode_PARALLEL.
        """
    @property
    def Specularity(self) -> float:
        """
        This attribute specifies the specularity of an extrusion object in percent.
        """
    @property
    def ViewPoint(self) -> 'Position3D_bddc0bc0':
        """
        This attribute specifies the viewpoint of the observer.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
"""
Const

Constants to use with XExtendedCalendar.getDisplayString() and the XNativeNumberSupplier methods.

The constants have different meanings if used with different locales. However, NATNUM1 always tries to convert to a string matching the native number mode of the corresponding locale.

Where available, the corresponding Microsoft Excel (tm) DBNum number format code modifier is listed.

Modifiers supported by XExtendedCalendar.getDisplayString() are marked with CAL: for the specific language and the corresponding DBNum modifier and the NatNum values used for Y/M/D are listed

**since**

    OOo 1.1.2

See Also:
    `API NativeNumberMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1NativeNumberMode.html>`_
"""
NATNUM0: Literal[0]
"""
Transliteration to ASCII Arabic digits.

Try to convert any native number string to ASCII. If already ASCII it remains ASCII.
"""
NATNUM1: Literal[1]
"""
Transliteration in
Chinese: Chinese lower case characters; CAL: 1/7/7 [DBNum1]
Japanese: short Kanji characters [DBNum1]; CAL: 1/4/4 [DBNum1]
Korean: Korean lower case characters [DBNum1]; CAL: 1/7/7 [DBNum1]
Hebrew: Hebrew characters
Arabic: Arabic-Indic characters
Thai: Thai characters
Hindi: Indic-Devanagari characters
Odia: Odia (Oriya) characters
Marathi: Indic-Devanagari characters
Bengali: Bengali characters
Punjabi: Punjabi (Gurmukhi) characters
Gujarati: Gujarati characters
Tamil: Tamil characters
Telugu: Telugu characters
Kannada: Kannada characters
Malayalam: Malayalam characters
Lao: Lao characters
Tibetan: Tibetan characters
Burmese: Burmese (Myanmar) characters
Khmer: Khmer (Cambodian) characters
Mongolian: Mongolian characters
Nepali: Indic-Devanagari characters
Dzongkha: Tibetan characters
Farsi: East Arabic-Indic characters
Church Slavic: Cyrillic characters.
"""
NATNUM2: Literal[2]
"""
Transliteration in
Chinese: Chinese upper case characters; CAL: 2/8/8 [DBNum2]
Japanese: traditional Kanji characters; CAL: 2/5/5 [DBNum2]
Korean: Korean upper case characters [DBNum2]; CAL: 2/8/8 [DBNum2]
Hebrew: Hebrew numbering.
"""
NATNUM3: Literal[3]
"""
Transliteration in
Chinese: fullwidth Arabic digits; CAL: 3/3/3 [DBNum3]
Japanese: fullwidth Arabic digits; CAL: 3/3/3 [DBNum3]
Korean: fullwidth Arabic digits [DBNum3]; CAL: 3/3/3 [DBNum3].
"""
NATNUM4: Literal[4]
"""
Transliteration in
Chinese: lower case text [DBNum1]
Japanese: modern long Kanji text [DBNum2]
Korean: formal lower case text.
"""
NATNUM5: Literal[5]
"""
Transliteration in
Chinese: Chinese upper case text [DBNum2]
Japanese: traditional long Kanji text [DBNum3]
Korean: formal upper case text.
"""
NATNUM6: Literal[6]
"""
Transliteration in
Chinese: fullwidth text [DBNum3]
Japanese: fullwidth text
Korean: fullwidth text.
"""
NATNUM7: Literal[7]
"""
Transliteration in
Chinese: short lower case text
Japanese: modern short Kanji text
Korean: informal lower case text.
"""
NATNUM8: Literal[8]
"""
Transliteration in
Chinese: short upper case text
Japanese: traditional short Kanji text [DBNum4]
Korean: informal upper case text.
"""
NATNUM9: Literal[9]
"""
Transliteration in
Korean: Hangul characters.
"""
NATNUM10: Literal[10]
"""
Transliteration in
Korean: formal Hangul text [DBNum4]; CAL: 9/11/11 [DBNum4].
"""
NATNUM11: Literal[11]
"""
Transliteration in
Korean: informal Hangul text.
"""
NATNUM12: Literal[12]
"""
Transliteration to cardinal number names (one, two, three, ...), ordinal number names (first, second, third, ...), ordinal indicators (1st, 2nd, 3rd, ...), etc.

Uses NatNum params string
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
import typing
from .x_text_content import XTextContent as XTextContent_b16e0ba5
if typing.TYPE_CHECKING:
    from .text_content_anchor_type import TextContentAnchorType as TextContentAnchorType_2cbe0f4a
    from .wrap_text_mode import WrapTextMode as WrapTextMode_b1dd0b91

class TextContent(XTextContent_b16e0ba5):
    """
    Service Class

    is an object which can be anchored in a text, like instances of TextFrame or TextField.
    
    If the concrete TextContent has a textual representation which fades into the surrounding text, then XTextField is used.
    
    If the concrete TextContent has a \"floating\" object, like a graphic, com.sun.star.drawing.XShape is used.

    See Also:
        `API TextContent <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextContent.html>`_
    """
    @property
    def AnchorTypes(self) -> 'typing.Tuple[TextContentAnchorType_2cbe0f4a, ...]':
        """
        contains the anchor type of the text content.
        """
    @property
    def AnchorType(self) -> 'TextContentAnchorType_2cbe0f4a':
        """
        specifies how the text content is attached to its surrounding Text.
        """
    @property
    def TextWrap(self) -> 'WrapTextMode_b1dd0b91':
        """
        specifies if the text content is a shape and how the text is wrapped around the shape.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class CheckinArgument(object):
    """
    Struct Class

    contains information needed to checkin a document.
    
    The checkin command is always called on the target private working copy document.

    See Also:
        `API CheckinArgument <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1CheckinArgument.html>`_
    """
    typeName: Literal['com.sun.star.ucb.CheckinArgument']

    def __init__(self, MajorVersion: typing.Optional[bool] = ..., VersionComment: typing.Optional[str] = ..., SourceURL: typing.Optional[str] = ..., TargetURL: typing.Optional[str] = ..., NewTitle: typing.Optional[str] = ..., MimeType: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            MajorVersion (bool, optional): MajorVersion value.
            VersionComment (str, optional): VersionComment value.
            SourceURL (str, optional): SourceURL value.
            TargetURL (str, optional): TargetURL value.
            NewTitle (str, optional): NewTitle value.
            MimeType (str, optional): MimeType value.
        """


    @property
    def MajorVersion(self) -> bool:
        """
        Tells whether to create a new major or minor version during the checkin.
        """


    @property
    def VersionComment(self) -> str:
        """
        Contains the version comment to set during the checkin.
        """


    @property
    def SourceURL(self) -> str:
        """
        contains the URL of the source of the action (e.g.
        
        the URL of the temporary file to checkin).
        """


    @property
    def TargetURL(self) -> str:
        """
        contains the URL of the private working copy to checkin.
        """


    @property
    def NewTitle(self) -> str:
        """
        contains the title of the transferred object, if it is different from the original one.
        
        If this field is filled, for example, a file will be renamed while it is being checked in.
        """


    @property
    def MimeType(self) -> str:
        """
        contains the Mime-Type of the content to check-in as it may be different from the original one.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2
import typing
from .data_point_properties import DataPointProperties as DataPointProperties_24a00efd
from .x_data_series import XDataSeries as XDataSeries_b8150b89
from .x_regression_curve_container import XRegressionCurveContainer as XRegressionCurveContainer_8801116d
from .data.x_data_sink import XDataSink as XDataSink_dbc40c7b
from .data.x_data_source import XDataSource as XDataSource_f6340d57
if typing.TYPE_CHECKING:
    from .stacking_direction import StackingDirection as StackingDirection_8060e21

class DataSeries(DataPointProperties_24a00efd, XDataSeries_b8150b89, XRegressionCurveContainer_8801116d, XDataSink_dbc40c7b, XDataSource_f6340d57):
    """
    Service Class

    reflects the model data of the object that has all the information for a DataRenderer to create a visible data series in a chart.
    
    It combines one or more DataSequences which are interpreted by evaluating their role-string.
    
    **since**
    
        LibreOffice 7.0

    See Also:
        `API DataSeries <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1DataSeries.html>`_
    """
    @property
    def AttributedDataPoints(self) -> 'typing.Tuple[int, ...]':
        """
        This service will be used to render this data series.
        
        This service name can be used to determine which DataSeries are of the same type.
        
        The result of the DataSeries.DataSequenceRoles depends on the renderer service set here.
        
        a sequence of indexes denoting which data points have set properties that differ from the default.
        
        The default values are determined by the properties set at the DataPointProperties of the data series.
        
        If the sequence is empty, that means that all data points look alike. They are formatted using the property values set in the data series.
        
        The indexes in this sequence match the indexes used by the XIndexContainer.
        
        This property is especially useful for large data series with only some formatted data points, because you do not have to iterate over all elements.
        """
    @property
    def DeletedLegendEntries(self) -> 'typing.Tuple[int, ...]':
        """
        A sequence of indexes denoting which data points shouldn't be shown in the legend.
        
        **since**
        
            LibreOffice 7.0
        """
    @property
    def AttachedAxisIndex(self) -> int:
        """
        This property describes whether the series should be shown at the main value axis or at the secondary value axis.
        
        Having this property not set or setting it to 0 means that this data series will be scaled at the primary y-axis ( of the coordinate system in which this series is hosted ).
        
        Setting this property to 1 means that this series should be scaled at the secondary y-axis. If there is no secondary axis the main axis should be used for scaling instead.
        
        If you want to scale a series at a different x or z axis you need to create an additional coordinate system and host this series there.
        """
    @property
    def ShowCustomLeaderLines(self) -> bool:
        """
        This property describes whether the data point and the data label are connected with a leader line.
        
        **since**
        
            LibreOffice 7.1
        """
    @property
    def ShowLegendEntry(self) -> bool:
        """
        This property describes whether the legend entry for the the data series should be shown.
        
        **since**
        
            LibreOffice 6.3
        """
    @property
    def StackingDirection(self) -> 'StackingDirection_8060e21':
        """
        indicates whether this series should be stacked with respect to the previous series.
        """
    @property
    def VaryColorsByPoint(self) -> bool:
        """
        If TRUE, the data points of this series get different colors by default, like in a pie chart.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.security
from typing_extensions import Literal
"""
Const

Constant definition of a certificate characters.

The certificate characters will be defined as bit-wise constants.

See Also:
    `API CertificateValidity <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1security_1_1CertificateValidity.html>`_
"""
VALID: Literal[0]
INVALID: Literal[1]
"""
The certificate is invalid.
"""
UNTRUSTED: Literal[2]
"""
The certificate itself is untrusted.
"""
TIME_INVALID: Literal[4]
"""
The current time is not in the range of time for which the certificate is valid.
"""
NOT_TIME_NESTED: Literal[8]
"""
The time range of a certificate does not fall within the time range of the issuing certificate.
"""
REVOKED: Literal[16]
"""
It is a revoked certificate.
"""
UNKNOWN_REVOKATION: Literal[32]
"""
The certificate revocation status is unknown.
"""
SIGNATURE_INVALID: Literal[64]
"""
The certificate signature is invalid.
"""
EXTENSION_INVALID: Literal[128]
"""
The certificate has invalid extensions.
"""
EXTENSION_UNKNOWN: Literal[256]
"""
The certificate has critical unknown extensions.
"""
ISSUER_UNKNOWN: Literal[512]
"""
The certificate issuer is unknown.
"""
ISSUER_UNTRUSTED: Literal[1024]
"""
The certificate issuer is untrusted.
"""
ISSUER_INVALID: Literal[4096]
"""
The certificate issuer is invalid.
"""
ROOT_UNKNOWN: Literal[8192]
"""
The root certificate is unknown.
"""
ROOT_UNTRUSTED: Literal[16384]
"""
The root certificate is untrusted.
"""
ROOT_INVALID: Literal[65536]
"""
The root certificate is invalid.
"""
CHAIN_INCOMPLETE: Literal[131072]
"""
The certificate chain is incomplete.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .outgoing_message_state import OutgoingMessageState as OutgoingMessageState_c200e54


class RecipientInfo(object):
    """
    Struct Class

    contains all information needed to send a message using one send protocol.
    
    To send one message via two different protocols, two RecipientInfos are needed - to send one message to different users with one protocol, one RecipientInfo can be used.

    See Also:
        `API RecipientInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1RecipientInfo.html>`_
    """
    typeName: Literal['com.sun.star.ucb.RecipientInfo']

    def __init__(self, ProtocolType: typing.Optional[str] = ..., State: typing.Optional[OutgoingMessageState_c200e54] = ..., To: typing.Optional[str] = ..., CC: typing.Optional[str] = ..., BCC: typing.Optional[str] = ..., Newsgroups: typing.Optional[str] = ..., Server: typing.Optional[str] = ..., Username: typing.Optional[str] = ..., Password: typing.Optional[str] = ..., VIMPostOfficePath: typing.Optional[str] = ..., ProtocolErrorString: typing.Optional[str] = ..., ProtocolErrorNumber: typing.Optional[int] = ..., SendTries: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            ProtocolType (str, optional): ProtocolType value.
            State (OutgoingMessageState, optional): State value.
            To (str, optional): To value.
            CC (str, optional): CC value.
            BCC (str, optional): BCC value.
            Newsgroups (str, optional): Newsgroups value.
            Server (str, optional): Server value.
            Username (str, optional): Username value.
            Password (str, optional): Password value.
            VIMPostOfficePath (str, optional): VIMPostOfficePath value.
            ProtocolErrorString (str, optional): ProtocolErrorString value.
            ProtocolErrorNumber (int, optional): ProtocolErrorNumber value.
            SendTries (int, optional): SendTries value.
        """


    @property
    def ProtocolType(self) -> str:
        """
        the protocol to use for sending (i.e.
        
        \"NNTP\", \"SMTP\", \"VIM\").
        """


    @property
    def State(self) -> OutgoingMessageState_c200e54:
        """
        the current state of the message.
        """


    @property
    def To(self) -> str:
        """
        the recipient(s) (e.g.
        
        e-mail address/es).
        
        Multiple addresses are separated by commas.
        """


    @property
    def CC(self) -> str:
        """
        the recipient(s) of a \"carbon copy\" (e.g.
        
        e-mail address/es).
        
        Multiple addresses are separated by commas.
        """


    @property
    def BCC(self) -> str:
        """
        the recipient(s) of \"blind carbon copy\" (e.g.
        
        e-mail address/es).
        
        Multiple addresses are separated by commas.
        """


    @property
    def Newsgroups(self) -> str:
        """
        the newsgroup(s) to which an article is be posted.
        
        Multiple addresses are separated by commas.
        """


    @property
    def Server(self) -> str:
        """
        the name of the server to be used for sending the message.
        """


    @property
    def Username(self) -> str:
        """
        the user name to be used for authorizing on the send server.
        """


    @property
    def Password(self) -> str:
        """
        the password to be used for authorizing on the send server.
        """


    @property
    def VIMPostOfficePath(self) -> str:
        """
        the Post Office Path (VIM only).
        """


    @property
    def ProtocolErrorString(self) -> str:
        """
        string representing the last error (generated by send server).
        """


    @property
    def ProtocolErrorNumber(self) -> int:
        """
        the number representing the last error (generated by send server).
        """


    @property
    def SendTries(self) -> int:
        """
        the count of tries to send a message.
        
        This count is 1 if the message was sent with the first try and increases with every unsuccessful retry.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.crypto
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ...mozilla.mozilla_product_type import MozillaProductType as MozillaProductType_2e210f5b


class NSSProfile(object):
    """
    Struct Class

    
    **since**
    
        LibreOffice 7.1

    See Also:
        `API NSSProfile <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1xml_1_1crypto_1_1NSSProfile.html>`_
    """
    typeName: Literal['com.sun.star.xml.crypto.NSSProfile']

    def __init__(self, Name: typing.Optional[str] = ..., Path: typing.Optional[str] = ..., Type: typing.Optional[MozillaProductType_2e210f5b] = ...) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Path (str, optional): Path value.
            Type (MozillaProductType, optional): Type value.
        """


    @property
    def Name(self) -> str:
        """
        the name of the NSS profile
        
        Normally the name will reflect the name of the Mozilla profile. But the profile list also contains the following special entries: MANUAL and MOZILLA_CERTIFICATE_FOLDER. These will have a product type of MozillaProductType.Default and might have an empty path, if that value is not available.
        """


    @property
    def Path(self) -> str:
        """
        the path to the NSS databases
        """


    @property
    def Type(self) -> MozillaProductType_2e210f5b:
        """
        the type of the NSS profile
        """


